@@ -34,7 +34,7 @@ gda_mail_command_new (GdaServerCommand * cmd)
 
 GdaServerRecordset *
 gda_mail_command_execute (GdaServerCommand * cmd,
-			  GdaServerError * error,
+			  GdaError * error,
 			  const GDA_CmdParameterSeq * params,
 			  gulong * affected, gulong options)
 {
