@@ -79,7 +79,7 @@ gint gda_mdb_connection_begin_transaction (GdaServerConnection *cnc);
 gint gda_mdb_connection_commit_transaction (GdaServerConnection *cnc);
 gint gda_mdb_connection_rollback_transaction (GdaServerConnection *cnc);
 GdaServerRecordset* gda_mdb_connection_open_schema (GdaServerConnection *cnc,
-						       GdaServerError *error,
+						       GdaError *error,
 						       GDA_Connection_QType t,
 						       GDA_Connection_Constraint *constraints,
 						       gint length);
@@ -104,7 +104,7 @@ void gda_mdb_connection_free (GdaServerConnection *cnc);
 
 gboolean gda_mdb_command_new (GdaServerCommand *cmd);
 GdaServerRecordset* gda_mdb_command_execute (GdaServerCommand *cmd,
-						GdaServerError *error,
+						GdaError *error,
 						const GDA_CmdParameterSeq *params,
 						gulong *affected,
 						gulong options);
@@ -116,7 +116,7 @@ gint     gda_mdb_recordset_move_prev (GdaServerRecordset *recset);
 gint     gda_mdb_recordset_close     (GdaServerRecordset *recset);
 void     gda_mdb_recordset_free      (GdaServerRecordset *recset);
 
-void gda_mdb_error_make (GdaServerError *error,
+void gda_mdb_error_make (GdaError *error,
 			   GdaServerRecordset *recset,
 			   GdaServerConnection *cnc,
 			   gchar *where);
